@@ -2,7 +2,7 @@ package Test2::Plugin::ExitSummary;
 use strict;
 use warnings;
 
-our $VERSION = '0.000072';
+our $VERSION = '0.000117';
 
 use Test2::API qw/test2_add_callback_exit/;
 
@@ -14,6 +14,9 @@ sub active { $ADDED_HOOK }
 sub summary {
     my ($ctx, $real, $new) = @_;
 
+    # Avoid double-printing diagnostics if Test::Builder already loaded.
+    return if $INC{'Test/Builder.pm'};
+
     my $hub    = $ctx->hub;
     my $plan   = $hub->plan;
     my $count  = $hub->count;
@@ -57,7 +60,7 @@ diagnostics.
 =head1 SOURCE
 
 The source code repository for Test2-Suite can be found at
-F<http://github.com/Test-More/Test2-Suite/>.
+F<https://github.com/Test-More/Test2-Suite/>.
 
 =head1 MAINTAINERS
 
@@ -77,7 +80,7 @@ F<http://github.com/Test-More/Test2-Suite/>.
 
 =head1 COPYRIGHT
 
-Copyright 2016 Chad Granum E<lt>exodist@cpan.orgE<gt>.
+Copyright 2018 Chad Granum E<lt>exodist@cpan.orgE<gt>.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
